import PropTypes from 'prop-types';
import { keys, omit } from 'ramda';
import React, { Component as ComponentBase } from 'react';
import { Button } from 'semantic-ui-react';

import { withSite } from '../../addons/Site';

/* Interface */
const propTypes = {
  /** An element type to render as (string or function). */
  as: PropTypes.oneOfType([
    PropTypes.func.isRequired,
    PropTypes.string.isRequired,
  ]),

  /** Event handler called after logout */
  onLogout: PropTypes.func,

  /**
   * StoryShare `Site`.
   * @private
   */
  site: PropTypes.object.isRequired,
};

/* Defaults */
const defaultProps = {
  as: Button,
};

/**
 * Logout control
 * Additional props will be passed through to SUI's `<Button>` or the component
 * specified by the `as` prop.
 * @returns {Object} component
 */
export class Logout extends ComponentBase {
  /**
   * Handles clicks on the rendered control
   * @returns {void}
   */
  handleClick = () => this.props.site.logout();

  render = () => {
    const { as: RenderComponent } = this.props;

    return (
      <RenderComponent
        { ...omit(keys(propTypes), this.props) }
        onClick={ this.handleClick }
      />
    );
  };
}

Logout.defaultProps = defaultProps;
Logout.propTypes = propTypes;

export default withSite(Logout);
