import { shallow } from 'enzyme';
import React from 'react';
import { Label } from 'semantic-ui-react';

import { Logout } from './Logout';

describe('Logout component', () => {
  const onLogout = jest.fn();

  const site = { logout: jest.fn() };

  let wrapper;

  beforeEach(() => {
    wrapper = shallow(
      <Logout
        onLogout={ onLogout }
        site={ site }
      >
        Log out text
      </Logout>
    );
  });

  it('renders', () => {
    expect(wrapper).toExist();
  });

  it('renders a button', () => {
    expect(wrapper.find('Button')).toExist();
  });

  it('passes unknown props through to the Button', () => {
    wrapper.setProps({ unknown: 'value' });
    expect(wrapper.find('Button')).toHaveProp('unknown', 'value');
  });

  it('avoids passing internal props through to the Button', () => {
    wrapper.setProps({ as: Label });
    const label = wrapper.find('Label');
    expect(label).not.toHaveProp('as');
    expect(label).not.toHaveProp('onLogout');
    expect(label).not.toHaveProp('site');
  });

  it('passes children through to the Button', () => {
    expect(wrapper.find('Button').children()).toHaveText('Log out text');
  });

  it('logs out when the button is clicked', () => {
    site.logout.mockClear();
    wrapper.find('Button').simulate('click');
    expect(site.logout).toHaveBeenCalled();
  });

  it('can render as a string component', () => {
    wrapper.setProps({ as: 'a' });
    expect(wrapper.find('Button')).not.toExist();
    expect(wrapper.find('a')).toExist();
  });

  it('can render as a functional component', () => {
    wrapper.setProps({ as: Label });
    expect(wrapper.find('Button')).not.toExist();
    expect(wrapper.find('Label')).toExist();
  });
});
