import getImageUrlByWidth from './getImageUrlByWidth';

describe('getImageUrlByWidth', () => {
  const SIZES_FIXTURE = {
    '1280x720': { source_url: 'path/1280x720', width: 1280 },
    '640x360': { source_url: 'path/640x360', width: 640 },
    '320x180': { source_url: 'path/320x180', width: 320 },
  };

  it('gets the matching size if the width matches exactly', () => {
    expect(getImageUrlByWidth(1280, SIZES_FIXTURE)).toBe('path/1280x720');
    expect(getImageUrlByWidth(640, SIZES_FIXTURE)).toBe('path/640x360');
    expect(getImageUrlByWidth(320, SIZES_FIXTURE)).toBe('path/320x180');
  });

  it('gets the next largest image if available', () => {
    expect(getImageUrlByWidth(1279, SIZES_FIXTURE)).toBe('path/1280x720');
    expect(getImageUrlByWidth(639, SIZES_FIXTURE)).toBe('path/640x360');
    expect(getImageUrlByWidth(319, SIZES_FIXTURE)).toBe('path/320x180');
  });

  it('gets the next smaller image if there is no larger image', () => {
    expect(getImageUrlByWidth(1281, SIZES_FIXTURE)).toBe('path/1280x720');
  });

  it('gets the smallest image if zero is passed', () => {
    expect(getImageUrlByWidth(0, SIZES_FIXTURE)).toBe('path/320x180');
  });

  it('gets the largest image if Infinity is passed', () => {
    expect(getImageUrlByWidth(Infinity, SIZES_FIXTURE)).toBe('path/1280x720');
  });
});
