import PropTypes from 'prop-types';
import React from 'react';
import { Segment } from 'semantic-ui-react';

import MediaImage from '../../../../elements/MediaImage';

/* Interface */
const propTypes = {
  /** Configured image alignment (if any) */
  align: PropTypes.string,

  /** Media ID of file */
  id: PropTypes.number,

  /** Configured image width */
  width: PropTypes.number.isRequired,
};

/* Defaults */
const defaultProps = {
  width: 100,
};

/**
 * Renders content from the `storyshare/image` block using item
 * @private
 * @param {Object} props - React component props.
 * @returns {Object} React element if id is provided.
 */
export const Image = ({ align, id, width }) => {
  if (!id) {
    return null;
  }

  const isCentred = align === 'center';

  const image = (
    <MediaImage
      aspectRatio={ false }
      centered={ isCentred }
      floated={ align === 'left' || align === 'right' ? align : null }
      id={ id }
      style={ { width: `${width}%` } }
    />
  );

  // If centred, wrap in a segment so the image can position itself
  return isCentred ? <Segment basic>{ image }</Segment> : image;
};

Image.defaultProps = defaultProps;
Image.propTypes = propTypes;

export default Image;
