import { shallow } from 'enzyme';
import React from 'react';

import { Image } from './Image';

describe('Image block', () => {
  let wrapper;

  beforeEach(() => {
    wrapper = shallow(
      <Image id={ 42 } />
    );
  });

  it('renders', () => {
    expect(wrapper).toExist();
  });

  it('suppresses rendering if there is no image ID', () => {
    wrapper.setProps({ id: undefined });
    expect(wrapper).toBeEmptyRender();
  });

  it('renders a MediaImage', () => {
    const image = wrapper.find('MediaImage');
    expect(image).toExist();
    expect(image).toHaveProp('id', 42);
  });

  it('tells the MediaImage to use the native image aspect ratio', () => {
    expect(wrapper.find('MediaImage')).toHaveProp('aspectRatio', false);
  });

  it('floats the image if it is aligned to one side', () => {
    expect(wrapper.find('MediaImage')).toHaveProp('floated', null);

    wrapper.setProps({ align: 'left' });
    expect(wrapper.find('MediaImage')).toHaveProp('floated', 'left');

    wrapper.setProps({ align: 'center' });
    expect(wrapper.find('MediaImage')).toHaveProp('floated', null);

    wrapper.setProps({ align: 'right' });
    expect(wrapper.find('MediaImage')).toHaveProp('floated', 'right');
  });

  it('centres the image if it is aligned centrally', () => {
    expect(wrapper.find('MediaImage')).toHaveProp('centered', false);

    wrapper.setProps({ align: 'left' });
    expect(wrapper.find('MediaImage')).toHaveProp('centered', false);

    wrapper.setProps({ align: 'center' });
    expect(wrapper.find('MediaImage')).toHaveProp('centered', true);

    wrapper.setProps({ align: 'right' });
    expect(wrapper.find('MediaImage')).toHaveProp('centered', false);
  });

  it('wraps the image in a basic segment if it is aligned centrally', () => {
    wrapper.setProps({ align: 'center' });

    const segment = wrapper.find('MediaImage').parent();
    expect(segment).toExist();
    expect(segment).toHaveDisplayName('Segment');
    expect(segment).toHaveProp('basic', true);
  });

  it('marks the image as full width by default', () => {
    expect(wrapper.find('MediaImage')).toHaveStyle('width', '100%');
  });

  it('scales the image if a width is provided', () => {
    wrapper.setProps({ width: 42 });
    expect(wrapper.find('MediaImage')).toHaveStyle('width', '42%');
  });
});
